#[non_exhaustive]pub struct Remote {
pub name: String,
pub url: String,
}Expand description
One configured Git remote, as listed by git remote -v.
Git emits one row for each fetch and push URL. parse_remotes coalesces
those rows to one remote name and prefers its fetch URL.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringConfigured remote name (for example, origin).
url: StringThe remote’s fetch URL.