BisectResult

Type Alias BisectResult 

pub type BisectResult = BisectStep;
Backward-readable alias for BisectStep. Prefer BisectStep in new code.

Aliased Type

pub enum BisectResult {
    NextCandidate {
        revision: RevSpec,
    },
    FirstBad {
        revision: RevSpec,
    },
}

Variants



NextCandidate

Git checked out another revision for the consumer to test.

Fields

revision: RevSpec

The revision Git selected and checked out.



FirstBad

Git completed the search and identified the first bad revision.

Fields

revision: RevSpec

The first bad revision reported by Git.