pub fn resolve(
segments: &[ConflictSegment],
side: ResolutionSide,
) -> Result<String>Expand description
Produce the file content with every conflict resolved to side.
Errors with a clear message when side is ResolutionSide::Base and a
region has no base (2-way merge style records none).