WorktreeAdd

Struct WorktreeAdd 

#[non_exhaustive]
pub struct WorktreeAdd { pub path: PathBuf, pub new_branch: Option<String>, pub commitish: Option<String>, }
Options for GitApi::worktree_add (git worktree add).

#[non_exhaustive], so build it through WorktreeAdd::checkout / WorktreeAdd::create_branch rather than a struct literal.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
path: PathBuf

Filesystem path for the new worktree.

new_branch: Option<String>

Create and check out this new branch (-b <name>); None checks out an existing ref.

commitish: Option<String>

The commit/branch to base the worktree on; None defaults to HEAD.

Implementations

Source

impl WorktreeAdd

pub fn checkout(path: impl Into<PathBuf>, commitish: impl Into<String>) -> Self

A worktree at path checking out an existing commitish (e.g. a branch): git worktree add <path> <commitish>.

pub fn create_branch( path: impl Into<PathBuf>, name: impl Into<String>, commitish: impl Into<String>, ) -> Self

A worktree at path creating a new branch name based on commitish: git worktree add -b <name> <path> <commitish>.